Module sync
once_
cell
1.21.4
Module sync
Module Items
Structs
In crate once_
cell
once_cell
Module
sync
Thread-safe, blocking version of
OnceCell
.
Structs

Lazy
A value which is initialized on the first access.
Once
Cell
A thread-safe cell which can be written to only once.