Struct Lazy

struct Lazy<T, F = fn() -> T> { ... }

A value which is initialized on the first access.

This type is thread-safe and can be used in statics.

Example

use std::collections::HashMap;

use once_cell::sync::Lazy;

static HASHMAP: Lazy<HashMap<i32, String>> = Lazy::new(|| {
    println!("initializing");
    let mut m = HashMap::new();
    m.insert(13, "Spica".to_string());
    m.insert(74, "Hoyten".to_string());
    m
});

fn main() {
    println!("ready");
    std::thread::spawn(|| {
        println!("{:?}", HASHMAP.get(&13));
    }).join().unwrap();
    println!("{:?}", HASHMAP.get(&74));

    // Prints:
    //   ready
    //   initializing
    //   Some("Spica")
    //   Some("Hoyten")
}

Implementations

impl<T, F> Lazy<T, F>

const fn new(f: F) -> Lazy<T, F>

Creates a new lazy value with the given initializing function.

fn into_value(this: Lazy<T, F>) -> Result<T, F>

Consumes this Lazy returning the stored value.

Returns Ok(value) if Lazy is initialized and Err(f) otherwise.

impl<T, F: FnOnce() -> T> Lazy<T, F>

fn force(this: &Lazy<T, F>) -> &T

Forces the evaluation of this lazy value and returns a reference to the result. This is equivalent to the Deref impl, but is explicit.

Example

use once_cell::sync::Lazy;

let lazy = Lazy::new(|| 92);

assert_eq!(Lazy::force(&lazy), &92);
assert_eq!(&*lazy, &92);
fn force_mut(this: &mut Lazy<T, F>) -> &mut T

Forces the evaluation of this lazy value and returns a mutable reference to the result. This is equivalent to the Deref impl, but is explicit.

Example

use once_cell::sync::Lazy;

let mut lazy = Lazy::new(|| 92);

assert_eq!(Lazy::force_mut(&mut lazy), &mut 92);
fn get(this: &Lazy<T, F>) -> Option<&T>

Gets the reference to the result of this lazy value if it was initialized, otherwise returns None.

Example

use once_cell::sync::Lazy;

let lazy = Lazy::new(|| 92);

assert_eq!(Lazy::get(&lazy), None);
assert_eq!(&*lazy, &92);
assert_eq!(Lazy::get(&lazy), Some(&92));
fn get_mut(this: &mut Lazy<T, F>) -> Option<&mut T>

Gets the reference to the result of this lazy value if it was initialized, otherwise returns None.

Example

use once_cell::sync::Lazy;

let mut lazy = Lazy::new(|| 92);

assert_eq!(Lazy::get_mut(&mut lazy), None);
assert_eq!(&*lazy, &92);
assert_eq!(Lazy::get_mut(&mut lazy), Some(&mut 92));

impl<P, T> Receiver for Lazy<T, F>

impl<T> Any for Lazy<T, F>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Lazy<T, F>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Lazy<T, F>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for Lazy<T, F>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, F = fn() -> T> Freeze for Lazy<T, F>

impl<T, F> Send for Lazy<T, F>

impl<T, F> Unpin for Lazy<T, F>

impl<T, F> UnsafeUnpin for Lazy<T, F>

impl<T, F> UnwindSafe for Lazy<T, F>

impl<T, F: FnOnce() -> T> Deref for Lazy<T, F>

fn deref(self: &Self) -> &T

impl<T, F: FnOnce() -> T> DerefMut for Lazy<T, F>

fn deref_mut(self: &mut Self) -> &mut T

impl<T, F: RefUnwindSafe> RefUnwindSafe for Lazy<T, F>

impl<T, F: Send> Sync for Lazy<T, F>

impl<T, U> Into for Lazy<T, F>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Lazy<T, F>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Lazy<T, F>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<T: Default> Default for Lazy<T>

fn default() -> Lazy<T>

Creates a new lazy value using Default as the initializing function.

impl<T: fmt::Debug, F> Debug for Lazy<T, F>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result